@@ -126,9 +126,8 @@ class AlpacaClass(DriverData):
     def protocol(self, value):
         self.client.protocol = value
 
-    def getInitialConfig(self):
+    def workerConnectDevice(self):
         """
-
         :return: success of reconnecting to server
         """
         self.client.connected(Connected=True)
@@ -146,10 +145,6 @@ class AlpacaClass(DriverData):
             self.client.signals.deviceConnected.emit(f'{self.deviceName}')
             self.app.message.emit(f'ALPACA device found: [{self.deviceName}]', 0)
 
-        self.data['DRIVER_INFO.DRIVER_NAME'] = self.client.nameDevice()
-        self.data['DRIVER_INFO.DRIVER_VERSION'] = self.client.driverVersion()
-        self.data['DRIVER_INFO.DRIVER_EXEC'] = self.client.driverInfo()
-
         return True
 
     def startTimer(self):
@@ -172,15 +167,22 @@ class AlpacaClass(DriverData):
         self.cycleDevice.stop()
         return True
 
+    def workerGetInitialConfig(self):
+        """
+        :return:
+        """
+        self.data['DRIVER_INFO.DRIVER_NAME'] = self.client.nameDevice()
+        self.data['DRIVER_INFO.DRIVER_VERSION'] = self.client.driverVersion()
+        self.data['DRIVER_INFO.DRIVER_EXEC'] = self.client.driverInfo()
+        return True
+
     def workerPollStatus(self):
         """
         pollStatusWorker is the thread method to be called for collecting data
 
         :return: success
         """
-
         suc = self.client.connected()
-
         if self.deviceConnected and not suc:
             self.deviceConnected = False
             self.client.signals.deviceDisconnected.emit(f'{self.deviceName}')
@@ -191,9 +193,6 @@ class AlpacaClass(DriverData):
             self.client.signals.deviceConnected.emit(f'{self.deviceName}')
             self.app.message.emit(f'ALPACA device found: [{self.deviceName}]', 0)
 
-        else:
-            pass
-
         return suc
 
     def processPolledData(self):
@@ -204,10 +203,8 @@ class AlpacaClass(DriverData):
 
     def pollData(self):
         """
-
         :return: success
         """
-
         if not self.deviceConnected:
             return False
 
@@ -218,13 +215,24 @@ class AlpacaClass(DriverData):
 
     def pollStatus(self):
         """
-        workerPollStatus starts a thread every 1 second for polling.
-
         :return: success
         """
+        if not self.deviceConnected:
+            return False
+
         worker = Worker(self.workerPollStatus)
         self.threadPool.start(worker)
+        return True
 
+    def getInitialConfig(self):
+        """
+        :return: success
+        """
+        if not self.deviceConnected:
+            return False
+
+        worker = Worker(self.workerGetInitialConfig)
+        self.threadPool.start(worker)
         return True
 
     def startCommunication(self, loadConfig=False):
@@ -234,11 +242,10 @@ class AlpacaClass(DriverData):
         :param loadConfig:
         :return: True for test purpose
         """
-
-        worker = Worker(self.getInitialConfig)
+        worker = Worker(self.workerConnectDevice)
+        worker.signals.result.connect(self.getInitialConfig)
         worker.signals.finished.connect(self.startTimer)
         self.threadPool.start(worker)
-
         return True
 
     def stopCommunication(self):
