@@ -54,15 +54,15 @@ class AscomClass(DriverData, Signals):
         self.data = data
         self.propertyExceptions = []
         self.deviceName = ''
+        self.deviceConnected = False
+        self.serverConnected = False
+
         self.defaultConfig = {
             'ascom': {
                 'deviceName': '',
             }
         }
 
-        self.deviceConnected = False
-        self.serverConnected = False
-
         self.cyclePollStatus = QTimer()
         self.cyclePollStatus.setSingleShot(False)
         self.cyclePollStatus.timeout.connect(self.pollStatus)
@@ -87,66 +87,6 @@ class AscomClass(DriverData, Signals):
         self.client.connected = False
         return True
 
-    def isClientConnected(self):
-        """
-        :return:
-        """
-        return self.client.connected
-
-    def workerConnectAscomDevice(self):
-        """
-        As some ASCOM devices need some time to be able to connect, we try to
-        connect multiply (10) times with an waiting period 0f 250ms, so 2,5
-        seconds in total.
-
-        :return: true for test purpose
-        """
-        for retry in range(0, 10):
-            try:
-                self.connectClient()
-                self.log.debug(f'Connect to [{self.deviceName}]')
-
-            except Exception as e:
-                suc = False
-                t = f'Connection retry [{retry}]: [{self.deviceName}]: [{e}]'
-                self.log.warning(t)
-
-            else:
-                suc = self.isClientConnected()
-                if suc:
-                    t = f'[{self.deviceName}] connected, [{retry}] retries'
-                    self.log.debug(t)
-                    break
-
-            finally:
-                QTest.qWait(250)
-
-        else:
-            suc = False
-
-        if not suc:
-            self.app.message.emit(f'ASCOM connect error: [{self.deviceName}]', 2)
-            return False
-
-        if not self.serverConnected:
-            self.serverConnected = True
-            self.ascomSignals.serverConnected.emit()
-
-        if not self.deviceConnected:
-            self.deviceConnected = True
-            self.ascomSignals.deviceConnected.emit(f'{self.deviceName}')
-            self.app.message.emit(f'ASCOM device found:  [{self.deviceName}]', 0)
-        return True
-
-    def workerGetInitialConfig(self):
-        """
-        :return: true for test purpose
-        """
-        self.data['DRIVER_INFO.DRIVER_NAME'] = self.client.Name
-        self.data['DRIVER_INFO.DRIVER_VERSION'] = self.client.DriverVersion
-        self.data['DRIVER_INFO.DRIVER_EXEC'] = self.client.DriverInfo
-        return True
-
     def startTimer(self):
         """
         :return: true for test purpose
@@ -176,11 +116,12 @@ class AscomClass(DriverData, Signals):
             cmd = 'self.client.' + valueProp
             value = eval(cmd)
         except Exception as e:
-            t = f'Property [{valueProp}] is not implemented: {e}, cmd: [{cmd}]'
+            t = f'[{self.deviceName}]:[{cmd}], property [{valueProp}] not implemented: {e}'
             self.log.debug(t)
             self.propertyExceptions.append(valueProp)
         else:
-            self.log.trace(f'Property [{valueProp}] has value: [{value}]')
+            t = f'[{self.deviceName}]: property [{valueProp}] set to [{value}]'
+            self.log.trace(t)
         finally:
             return value
 
@@ -196,12 +137,14 @@ class AscomClass(DriverData, Signals):
             cmd = 'self.client.' + valueProp + ' = value'
             exec(cmd)
         except Exception as e:
-            t = f'Property [{valueProp}] is not implemented: {e}, cmd: [{cmd}]'
+            t = f'[{self.deviceName}]:[{cmd}], property [{valueProp}] not implemented: {e}'
             self.log.debug(t)
-            self.propertyExceptions.append(valueProp)
+            if valueProp != 'Connect':
+                self.propertyExceptions.append(valueProp)
             return False
         else:
-            self.log.trace(f'Property [{valueProp}] is set to [{value}]')
+            t = f'[{self.deviceName}]: property [{valueProp}] set to [{value}]'
+            self.log.trace(t)
             return True
 
     def callAscomMethod(self, method, param):
@@ -217,12 +160,13 @@ class AscomClass(DriverData, Signals):
             cmd = 'self.client.' + method + f'({paramStr})'
             exec(cmd)
         except Exception as e:
-            t = f'Method [{method}] is not implemented: {e}, cmd: [{cmd}]'
+            t = f'[{self.deviceName}]:[{cmd}], method [{method}] not implemented: {e}'
             self.log.debug(t)
             self.propertyExceptions.append(method)
             return False
         else:
-            self.log.trace(f'Method [{method}] is set to [{param}]')
+            t = f'[{self.deviceName}]: method [{method}] called [{param}]'
+            self.log.trace(t)
             return True
 
     def getAndStoreAscomProperty(self, valueProp, element, elementInv=None):
@@ -236,16 +180,62 @@ class AscomClass(DriverData, Signals):
         self.storePropertyToData(value, element, elementInv)
         return True
 
+    def workerConnectDevice(self):
+        """
+        As some ASCOM devices need some time to be able to connect, we try to
+        connect multiply (10) times with an waiting period 0f 250ms, so 2,5
+        seconds in total.
+
+        :return: true for test purpose
+        """
+        for retry in range(0, 10):
+            try:
+                self.connectClient()
+                self.log.debug(f'Connect to [{self.deviceName}]')
+            except Exception as e:
+                suc = False
+                t = f'Connection retry [{retry}]: [{self.deviceName}]: [{e}]'
+                self.log.warning(t)
+            else:
+                suc = self.getAscomProperty('connected')
+                if suc:
+                    t = f'[{self.deviceName}] connected, [{retry}] retries'
+                    self.log.debug(t)
+                    break
+            finally:
+                QTest.qWait(250)
+
+        else:
+            suc = False
+
+        if not suc:
+            self.app.message.emit(f'ASCOM connect error: [{self.deviceName}]', 2)
+            return False
+
+        if not self.serverConnected:
+            self.serverConnected = True
+            self.ascomSignals.serverConnected.emit()
+
+        if not self.deviceConnected:
+            self.deviceConnected = True
+            self.ascomSignals.deviceConnected.emit(f'{self.deviceName}')
+            self.app.message.emit(f'ASCOM device found:  [{self.deviceName}]', 0)
+        return True
+
+    def workerGetInitialConfig(self):
+        """
+        :return: true for test purpose
+        """
+        self.getAndStoreAscomProperty('Name', 'DRIVER_INFO.DRIVER_NAME')
+        self.getAndStoreAscomProperty('DriverVersion', 'DRIVER_INFO.DRIVER_VERSION')
+        self.getAndStoreAscomProperty('DriverInfo', 'DRIVER_INFO.DRIVER_EXEC')
+        return True
+
     def workerPollStatus(self):
         """
         :return: success
         """
-        try:
-            suc = self.isClientConnected()
-
-        except Exception as e:
-            self.log.info(f'Connection status error [{self.deviceName}]: [{e}]')
-            suc = False
+        suc = self.getAscomProperty('connected')
 
         if self.deviceConnected and not suc:
             self.deviceConnected = False
@@ -257,9 +247,6 @@ class AscomClass(DriverData, Signals):
             self.ascomSignals.deviceConnected.emit(f'{self.deviceName}')
             self.app.message.emit(f'ASCOM device found:  [{self.deviceName}]', 0)
 
-        else:
-            pass
-
         return suc
 
     @staticmethod
@@ -272,7 +259,7 @@ class AscomClass(DriverData, Signals):
         pythoncom.CoUninitialize()
         return result
 
-    def callMethodThreaded(self, fn, cb_res=None, cb_fin=None, check=True, *args, **kwargs):
+    def callMethodThreaded(self, fn, *args, cb_res=None, cb_fin=None, **kwargs):
         """
         callMethodThreaded is done mainly for ASCOM ctypes interfaces which take
         longer to end and should not slow down the gui thread itself. All called
@@ -284,19 +271,18 @@ class AscomClass(DriverData, Signals):
         pythoncom.CoUninitialize() after the functions finished.
 
         :param fn: function
+        :param args:
         :param cb_res: callback
         :param cb_fin: callback
-        :param check: callback
-        :param args:
         :param kwargs:
         :return:
         """
-        if check and not self.deviceConnected:
+        if not self.deviceConnected:
             return False
 
         worker = Worker(self.callerInitUnInit, fn, *args, **kwargs)
         if cb_res:
-            worker.signals.finished.connect(cb_res)
+            worker.signals.result.connect(cb_res)
         if cb_fin:
             worker.signals.finished.connect(cb_fin)
         self.threadPool.start(worker)
@@ -353,10 +339,11 @@ class AscomClass(DriverData, Signals):
             return False
 
         else:
-            self.callMethodThreaded(self.workerConnectAscomDevice,
-                                    check=False,
-                                    cb_res=self.getInitialConfig,
-                                    cb_fin=self.startTimer)
+            worker = Worker(self.callerInitUnInit, self.workerConnectDevice)
+            worker.signals.result.connect(self.getInitialConfig)
+            worker.signals.finished.connect(self.startTimer)
+            self.threadPool.start(worker)
+
         return True
 
     def stopCommunication(self):
