@@ -53,7 +53,6 @@ class Model:
         self.modelName = ''
         self.model = []
         self.imageDir = ''
-        self.statusDAT = None
         self.modelBuildRetryCounter = 0
 
         ms = self.app.mount.signals
@@ -396,29 +395,6 @@ class Model:
 
         return True
 
-    def disableDAT(self):
-        """
-        :return: True for test purpose
-        """
-        if self.statusDAT is None:
-            self.statusDAT = self.app.mount.setting.statusDualAxisTracking
-
-        self.statusDAT = self.app.mount.setting.statusDualAxisTracking
-        self.app.mount.setting.setDualAxisTracking(False)
-        self.changeStyleDynamic(self.ui.statusDualAxisTracking, 'color', 'yellow')
-        return True
-
-    def restoreStatusDAT(self):
-        """
-        :return: true for test purpose
-        """
-        if self.statusDAT is None:
-            return False
-
-        self.app.mount.setting.setDualAxisTracking(self.statusDAT)
-        self.changeStyleDynamic(self.ui.statusDualAxisTracking, 'color', '')
-        return True
-
     def clearQueues(self):
         """
         :return: true for test purpose
@@ -554,7 +530,6 @@ class Model:
 
         :return: true for test purpose
         """
-        self.restoreStatusDAT()
         self.app.camera.abort()
         self.app.astrometry.abort()
         self.restoreSignalsModelDefault()
@@ -691,7 +666,6 @@ class Model:
         self.restoreSignalsModelDefault()
         self.clearQueues()
         self.restoreModelDefaultContextAndGuiStatus()
-        self.restoreStatusDAT()
         if len(self.model) < 3:
             return False
 
@@ -952,7 +926,6 @@ class Model:
             return False
 
         self.setupModelRunContextAndGuiStatus()
-        self.disableDAT()
         self.app.message.emit(f'Modeling start:      {self.modelName}', 1)
         self.modelBuildRetryCounter = self.ui.numberBuildRetries.value()
         self.modelCycleThroughBuildPoints(modelPoints=modelPoints)
