@@ -31,7 +31,7 @@ class Styles:
     COLOR_BLUE2 = QColor(80, 140, 176)
     COLOR_BLUE3 = QColor(48, 104, 128)
     COLOR_BLUE4 = QColor(44, 80, 112)
-    COLOR_YELLOW = QColor(192, 192, 0)
+    COLOR_YELLOW = QColor(255, 255, 0)
     COLOR_GREEN = QColor(0, 255, 0)
     COLOR_WHITE = QColor(255, 255, 255)
     COLOR_WHITE1 = QColor(224, 224, 224)
@@ -49,8 +49,15 @@ class Styles:
     BACK_RED = 'background-color: red;'
     BACK_GREEN = 'background-color: green;'
     BACK_NORM = 'background-color: #202020;'
+    BACK_BACK = 'background-color: #181818'
+    BACK_BLUE1 = 'background-color: #104860'
+    BACK_BLUE2 = 'background-color: #0C3648'
+    BACK_BLUE3 = 'background-color: #082430'
+    BACK_BLUE4 = 'background-color: #061828'
 
     M_TRANS = '#20202000'
+    M_BACK = '#181818'
+    M_BLUE_H = '#30C0FF'
     M_BLUE = '#2090C0'
     M_BLUE1 = '#104860'
     M_BLUE2 = '#0C3648'
@@ -60,18 +67,22 @@ class Styles:
     M_WHITE_H = '#F0F0F0'
     M_WHITE = '#A0A0A0'
     M_WHITE_L = '#808080'
+    M_GREY_H = '#606060'
     M_GREY = '#404040'
     M_GREY_MID = '#303030'
+    M_GREY_LL = '#282828'
     M_GREY_LIGHT = '#202020'
     M_GREY_DARK = '#101010'
     M_GREEN_H = '#00A000'
     M_GREEN = '#008000'
-    M_GREEN_L = '#004000'
+    M_GREEN_L = '#006000'
     M_GREEN_LL = '#003000'
     M_GREEN_LL_A = '#00100040'
     M_RED = '#B03030'
+    M_RED_L = '#802020'
     M_PINK_H = '#FF00FF'
     M_PINK = '#B000B0'
+    M_PINK_L = '#800080'
     M_YELLOW_H = '#FFFF00'
     M_YELLOW = '#C0C000'
     M_YELLOW_L = '#808000'
@@ -99,13 +110,13 @@ class Styles:
         font-size: 11pt;
     }
     QTextBrowser {
-        font-family: Courier;
-        font-weight: normal;
+        font-family: Courier New;
+        font-weight: bold;
         font-size: 13pt;
     }
     QListWidget {
-        font-family: Courier;
-        font-weight: normal;
+        font-family: Courier New;
+        font-weight: bold;
         font-size: 13pt;
     }
     QToolTip {
@@ -133,17 +144,17 @@ class Styles:
     QGroupBox {
         font-family: Arial;
         font-weight: normal;
-        font-size: 9pt;
+        font-size: 8pt;
     }
     QTextBrowser {
-        font-family: Courier;
-        font-weight: normal;
-        font-size: 8pt;
+        font-family: Courier New;
+        font-weight: bold;
+        font-size: 9pt;
     }
     QListWidget {
-        font-family: Courier;
-        font-weight: normal;
-        font-size: 8pt;
+        font-family: Courier New;
+        font-weight: bold;
+        font-size: 9pt;
     }
     QToolTip {
         font-size: 10pt;
@@ -166,7 +177,7 @@ class Styles:
         background-color: #202020;
         color: rgb(32, 144, 192);
         padding: 5px;
-        max-width: 300px;
+        max-width: 500px;
     }
     QLabel {
         background-color: transparent;
@@ -223,6 +234,30 @@ class Styles:
         border-style: outset;
         border-color: red;
     }
+    QLineEdit[char='green'] {
+        color: #00C000;
+    }
+    QLineEdit[char='yellow'] {
+        color: '#C0C000';
+    }
+    QLineEdit[char='red'] {
+        color: #C00000;
+    }
+    QLineEdit[color='M_RED_L'] {
+        border-width: 2px;
+        border-style: outset;
+        border-color: #802020;
+    }
+    QLineEdit[color='M_YELLOW_L'] {
+        border-width: 2px;
+        border-style: outset;
+        border-color: #808000;
+    }
+    QLineEdit[color='M_GREEN_L'] {
+        border-width: 2px;
+        border-style: outset;
+        border-color: #006000;
+    }
     QLineEdit[status='on'] {
         color: black;
         border-width: 2px;
@@ -261,9 +296,6 @@ class Styles:
         color: rgb(32, 144, 196);
         background-color: #181818;
     }
-    QGroupBox::title:disabled {
-        color: #404040;
-    }
     QGroupBox::title[refraction='true']{
         color: rgb(32, 144, 192);
     }
@@ -308,6 +340,10 @@ class Styles:
         background-color: rgb(32, 144, 192);
         image: url(:/icon/checkmark.ico);
     }
+    QCheckBox::indicator:disabled {
+        background-color: transparent;
+        image: None;
+    }
     QCheckBox:disabled {
         color: #404040;
     }
@@ -343,6 +379,10 @@ class Styles:
         border-radius: 2px;
         padding-right: 2px;
     }
+    QDoubleSpinBox:disabled {
+        background-color: #202020;
+        color: #404040;
+    }
     QDoubleSpinBox::up-button {
         subcontrol-origin: border;
         subcontrol-position: top right;
@@ -491,7 +531,7 @@ class Styles:
     }
     QPushButton:disabled {
         background-color: #101010;
-        color: #606060;
+        color: #404040;
         border-color: #202020;
         border-width: 1px;
         border-style: outset;
@@ -513,6 +553,11 @@ class Styles:
         background-color: green;
         color: #000000;
     }
+    QPushButton[stop='true'] {
+        background-color: transparent;
+        color: transparent;
+        border-color: transparent;
+    }
     /* Combo Boxes */
     QComboBox {
         combobox-popup: 0;
@@ -674,6 +719,14 @@ class Styles:
         border-color: #404040;
         border-style: outset;
     }
+    QProgressBar:disabled {
+        color: #404040;
+        background-color: #101010;
+        border-radius: 3px;
+        border-width: 1px;
+        border-color: #202020;
+        border-style: outset;
+    }
     QProgressBar::chunk {
         background-color: rgb(32, 144, 192);
         width: 1px;
