@@ -17,7 +17,6 @@
 ###########################################################
 # standard libraries
 import logging
-from threading import Lock
 import bisect
 
 # external packages
@@ -66,6 +65,7 @@ class ToolsMatplotlib:
             else:
                 if indexValue.startswith(searchString):
                     return index
+
         return 0
 
     @staticmethod
@@ -97,12 +97,14 @@ class ToolsMatplotlib:
         staticCanvas.setParent(widget)
         return staticCanvas
 
-    def generatePolar(self, widget=None, title='', horizon=False, showAxes=True):
+    def generatePolar(self, widget=None, title='', horizon=False,
+                      showAxes=True, reverse=False):
         """
         :param widget:
         :param title:
         :param horizon:
         :param showAxes:
+        :param reverse: does change E/W setting
         :return:
         """
         if widget is None:
@@ -110,7 +112,6 @@ class ToolsMatplotlib:
         if not hasattr(widget, 'figure'):
             return None, None
 
-        lock = Lock()
         if showAxes:
             color = self.M_BLUE
             colorGrid = self.M_GREY
@@ -119,41 +120,45 @@ class ToolsMatplotlib:
             color = self.M_TRANS
             colorGrid = self.M_TRANS
 
-        with lock:
-            figure = widget.figure
+        figure = widget.figure
 
-            if figure.axes:
-                axe = figure.axes[0]
-                axe.cla()
+        if figure.axes:
+            axe = figure.axes[0]
+            axe.cla()
 
-            else:
-                figure.clf()
-                axe = figure.add_subplot(1, 1, 1, polar=True, facecolor='None')
+        else:
+            figure.clf()
+            axe = figure.add_subplot(1, 1, 1, polar=True, facecolor='None')
 
-            axe.grid(True, color=colorGrid)
+        axe.grid(True, color=colorGrid)
 
-            if title:
-                axe.set_title(title, color=color, fontweight='bold', pad=15)
+        if title:
+            axe.set_title(title, color=color, fontweight='bold', pad=15)
 
-            axe.set_xlabel('', color=color, fontweight='bold', fontsize=12)
-            axe.set_ylabel('', color=color, fontweight='bold', fontsize=12)
-            axe.tick_params(axis='x', colors=color, labelsize=12)
-            axe.tick_params(axis='y', colors=color, labelsize=12)
-            axe.set_theta_zero_location('N')
-            axe.set_rlabel_position(45)
+        axe.set_xlabel('', color=color, fontweight='bold', fontsize=12)
+        axe.set_ylabel('', color=color, fontweight='bold', fontsize=12)
+        axe.tick_params(axis='x', colors=color, labelsize=12)
+        axe.tick_params(axis='y', colors=color, labelsize=12)
+        axe.set_theta_zero_location('N')
+        axe.set_rlabel_position(45)
+        axe.spines['polar'].set_color(color)
+
+        if reverse:
+            axe.set_theta_direction(1)
+        else:
             axe.set_theta_direction(-1)
-            axe.spines['polar'].set_color(color)
-            axe.set_xticks(np.radians([0, 45, 90, 135, 180, 225, 270, 315]))
-            axe.set_xticklabels(['N', 'NE', 'E', 'SE', 'S', 'SW', 'W', 'NW'])
 
-            if not horizon:
-                return axe, figure
+        axe.set_xticks(np.radians([0, 45, 90, 135, 180, 225, 270, 315]))
+        axe.set_xticklabels(['N', 'NE', 'E', 'SE', 'S', 'SW', 'W', 'NW'])
 
-            axe.set_ylim(0, 90)
-            axe.set_yticks(range(0, 91, 15))
-            axe.set_yticklabels(['', '75', '60', '45', '30', '15', ''])
+        if not horizon:
             return axe, figure
 
+        axe.set_ylim(0, 90)
+        axe.set_yticks(range(0, 90, 10))
+        axe.set_yticklabels(['', '80', '70', '60', '50', '40', '30', '20', '10'])
+        return axe, figure
+
     def generateFlat(self, widget=None, title='', horizon=False, showAxes=True):
         """
         :param widget:
@@ -167,58 +172,53 @@ class ToolsMatplotlib:
         if not hasattr(widget, 'figure'):
             return None, None
 
-        lock = Lock()
-
         if showAxes:
             color = self.M_BLUE
-
         else:
             color = self.M_TRANS
 
-        with lock:
-            figure = widget.figure
+        figure = widget.figure
 
-            if figure.axes:
-                axe = figure.axes[0]
-                axe.cla()
+        if figure.axes:
+            axe = figure.axes[0]
+            axe.cla()
+        else:
+            figure.clf()
+            axe = figure.add_subplot(1, 1, 1, facecolor='None')
 
-            else:
-                figure.clf()
-                axe = figure.add_subplot(1, 1, 1, facecolor='None')
+        axe.spines['bottom'].set_color(color)
+        axe.spines['top'].set_color(color)
+        axe.spines['left'].set_color(color)
+        axe.spines['right'].set_color(color)
 
-            axe.spines['bottom'].set_color(color)
-            axe.spines['top'].set_color(color)
-            axe.spines['left'].set_color(color)
-            axe.spines['right'].set_color(color)
+        if showAxes:
+            axe.grid(showAxes, color=self.M_GREY)
+        else:
+            axe.grid(showAxes)
 
-            if showAxes:
-                axe.grid(showAxes, color=self.M_GREY)
+        if title:
+            axe.set_title(title, color=color, fontweight='bold', pad=15)
 
-            else:
-                axe.grid(showAxes)
+        axe.set_xlabel('', color=color, fontweight='bold', fontsize=12)
+        axe.set_ylabel('', color=color, fontweight='bold', fontsize=12)
+        axe.tick_params(axis='x', colors=color, labelsize=12)
+        axe.tick_params(axis='y', colors=color, labelsize=12)
 
-            if title:
-                axe.set_title(title, color=color, fontweight='bold', pad=15)
-
-            axe.set_xlabel('', color=color, fontweight='bold', fontsize=12)
-            axe.set_ylabel('', color=color, fontweight='bold', fontsize=12)
-            axe.tick_params(axis='x', colors=color, labelsize=12)
-            axe.tick_params(axis='y', colors=color, labelsize=12)
-
-            if not horizon:
-                return axe, figure
-
-            axe.set_xlim(0, 360)
-            axe.set_ylim(0, 90)
-            axe.set_xticks(np.arange(0, 361, 45))
-            axe.set_xticklabels(['0 N', '45 NE', '90 E', '135 SE', '180 S',
-                                 '225 SW', '270 W', '315 NW', '360 N'])
-            axe.set_xlabel('Azimuth [degrees]', color=color,
-                           fontweight='bold', fontsize=12)
-            axe.set_ylabel('Altitude [degrees]', color=color,
-                           fontweight='bold', fontsize=12)
+        if not horizon:
             return axe, figure
 
+        axe.set_xlim(0, 360)
+        axe.set_ylim(0, 90)
+        axe.set_xticks(np.arange(0, 361, 45))
+        axe.set_xticklabels(['0 N', '45 NE', '90 E', '135 SE', '180 S',
+                             '225 SW', '270 W', '315 NW', '360 N'])
+        axe.set_xlabel('Azimuth [degrees]', color=color, fontweight='bold',
+                       fontsize=12)
+        axe.set_ylabel('Altitude [degrees]', color=color, fontweight='bold',
+                       fontsize=12)
+
+        return axe, figure
+
     def generateColorbar(self, figure=None, scatter=None, label=''):
         """
         :param figure:
@@ -240,6 +240,7 @@ class ToolsMatplotlib:
         figure.axes[1].set_ylabel(label, color=self.M_BLUE)
         figure.axes[1].tick_params(axis='y', labelcolor=self.M_BLUE,
                                    color=self.M_BLUE)
+
         return True
 
     @staticmethod
@@ -247,7 +248,8 @@ class ToolsMatplotlib:
         """
         getIndexPoint returns the index of the point which is nearest to the
         coordinate of the mouse click when the click is in distance epsilon of
-        the points. otherwise no index will be returned.
+        the points. otherwise
+        no index will be returned.
 
         :param event: data of the mouse clicked event
         :param plane: coordinates as tuples (alt, az)
@@ -291,25 +293,3 @@ class ToolsMatplotlib:
         xt = [i[1] for i in plane]
         index = int(bisect.bisect_left(xt, x))
         return index
-
-    @staticmethod
-    def writeRetrofitData(mountModel, buildModel):
-        """
-        :param mountModel:
-        :param buildModel:
-        :return:
-        """
-        for i, mPoint in enumerate(buildModel):
-            mPoint['errorRMS'] = mountModel.starList[i].errorRMS
-            mPoint['errorAngle'] = mountModel.starList[i].errorAngle.degrees
-            mPoint['haMountModel'] = mountModel.starList[i].coord.ra.hours
-            mPoint['decMountModel'] = mountModel.starList[i].coord.dec.degrees
-            mPoint['errorRA'] = mountModel.starList[i].errorRA()
-            mPoint['errorDEC'] = mountModel.starList[i].errorDEC()
-            mPoint['errorIndex'] = mountModel.starList[i].number
-            mPoint['modelTerms'] = mountModel.terms
-            mPoint['modelErrorRMS'] = mountModel.errorRMS
-            mPoint['modelOrthoError'] = mountModel.orthoError.degrees * 3600
-            mPoint['modelPolarError'] = mountModel.polarError.degrees * 3600
-
-        return buildModel
