@@ -177,10 +177,11 @@ class Astrometry:
         if not updateFits:
             return solve, fitsHeader
 
-        fitsHeader.append(('SCALE', solve['scaleS'], 'MountWizzard4'))
-        fitsHeader.append(('PIXSCALE', solve['scaleS'], 'MountWizzard4'))
-        fitsHeader.append(('ANGLE', solve['angleS'], 'MountWizzard4'))
-        fitsHeader.append(('MIRRORED', solve['mirroredS'], 'MountWizzard4'))
+        fitsHeader.append(('SCALE', solve['scaleS'], 'MW4 - solved parameters'))
+        fitsHeader.append(('PIXSCALE', solve['scaleS'], 'MW4 - solved parameters'))
+        fitsHeader.append(('ANGLE', solve['angleS'], 'MW4 - solved parameters'))
+        fitsHeader.append(('MIRRORED', solve['mirroredS'], 'MW4 - solved parameters'))
+        fitsHeader.append(('COMMENT', 'There was a cleanup of parameters as well') )
 
         fitsHeader.extend(wcsHeader,
                           unique=True,
