@@ -23,12 +23,24 @@ from astropy.io import fits
 from PyQt5.QtTest import QTest
 
 # local imports
+from mountcontrol.convert import sexagesimalizeToInt
 from base.alpacaClass import AlpacaClass
 from base.alpacaBase import Camera
 from base.tpool import Worker
 from base.transform import JNowToJ2000
 
 
+def formatDstrToText(angle):
+    """
+    :param angle:
+    :return:
+    """
+    sgn, d, m, s, frac = sexagesimalizeToInt(angle.degrees, 0)
+    sign = '+' if sgn >= 0 else '-'
+    text = f'{sign}{d:02d} {m:02d} {s:02d}'
+    return text
+
+
 class CameraAlpaca(AlpacaClass):
     """
     the class CameraAlpaca inherits all information and handling of the CameraAlpaca device.
@@ -86,13 +98,13 @@ class CameraAlpaca(AlpacaClass):
         self.storePropertyToData(self.client.gain(), 'CCD_GAIN.GAIN')
         self.storePropertyToData(self.client.offset(), 'CCD_OFFSET.OFFSET')
         self.storePropertyToData(self.client.fastreadout(),
-                       'READOUT_QUALITY.QUALITY_LOW',
-                       'READOUT_QUALITY.QUALITY_HIGH')
+                                 'READOUT_QUALITY.QUALITY_LOW',
+                                 'READOUT_QUALITY.QUALITY_HIGH')
         self.storePropertyToData(self.client.ccdtemperature(),
-                       'CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE')
+                                 'CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE')
         self.storePropertyToData(self.client.cooleron(), 'CCD_COOLER.COOLER_ON')
         self.storePropertyToData(self.client.coolerpower(),
-                       'CCD_COOLER_POWER.CCD_COOLER_VALUE')
+                                 'CCD_COOLER_POWER.CCD_COOLER_VALUE')
 
         return True
 
@@ -192,6 +204,8 @@ class CameraAlpaca(AlpacaClass):
 
             if focalLength:
                 factor = binning / focalLength * 206.265
+                header.append(('FOCALLEN', focalLength,
+                               'Data taken from driver or manual input'))
             else:
                 factor = 1
 
@@ -200,14 +214,24 @@ class CameraAlpaca(AlpacaClass):
             header.append(('YBINNING', binning, 'MW4 is using the same binning for x and y'))
             header.append(('EXPTIME', expTime))
             header.append(('OBSERVER', 'MW4'))
-            header.append(('DATE-OBS', self.app.mount.obsSite.timeJD.utc_iso(), 'Time from UTC is ISO format'))
+            timeJD = self.app.mount.obsSite.timeJD
+            header.append(('DATE-OBS', timeJD.tt_strftime('%Y-%m-%dT%H:%M:%S'),
+                           'Time is UTC of mount'))
             header.append(('CCD-TEMP', self.data.get('CCD_TEMPERATURE.CCD_TEMPERATURE_VALUE', 0)))
             header.append(('SQM', self.app.skymeter.data.get('SKY_QUALITY.SKY_BRIGHTNESS', 0)))
 
             if isMount:
-                header.append(('RA', ra._degrees, 'Float value in degree'))
-                header.append(('DEC', dec.degrees, 'Float value in degree'))
-                header.append(('TELESCOP', self.app.mount.firmware.product, 'Mount version from firmware'))
+                header.append(('RA', ra._degrees))
+                header.append(('DEC', dec.degrees))
+                header.append(('TELESCOP',
+                               self.app.mount.firmware.product,
+                               'Mount version from firmware'))
+                lat = self.app.mount.obsSite.location.latitude
+                header.append(('SITELAT', formatDstrToText(lat)))
+                lon = self.app.mount.obsSite.location.longitude
+                header.append(('SITELON', formatDstrToText(lon)))
+                elev = self.app.mount.obsSite.location.elevation.m
+                header.append(('SITEELEV', elev))
 
             hdu.writeto(imagePath, overwrite=True, output_verify='silentfix+warn')
             self.log.info(f'Saved Image: [{imagePath}]')
