@@ -32,36 +32,23 @@ class SkymeterAscom(AscomClass):
     __all__ = ['SkymeterAscom',
                ]
 
-    # specific timing for device
-    CYCLE_DEVICE = 3000
-    CYCLE_DATA = 1000
-
     def __init__(self, app=None, signals=None, data=None):
         super().__init__(app=app, data=data, threadPool=app.threadPool)
 
         self.signals = signals
         self.data = data
 
-    def getInitialConfig(self):
+    def workerGetInitialConfig(self):
         """
-
         :return: true for test purpose
         """
-
-        super().getInitialConfig()
-
+        super().workerGetInitialConfig()
         return True
 
     def workerPollData(self):
         """
-
         :return: true for test purpose
         """
-
-        if not self.deviceConnected:
-            return False
-
-        self.dataEntry(self.client.temperature, 'SKY_QUALITY.SKY_TEMPERATURE')
-        self.dataEntry(self.client.skyquality, 'SKY_QUALITY.SKY_BRIGHTNESS')
-
+        self.getAndStoreAscomProperty('temperature', 'SKY_QUALITY.SKY_TEMPERATURE')
+        self.getAndStoreAscomProperty('skyquality', 'SKY_QUALITY.SKY_BRIGHTNESS')
         return True
